@@ -14,8 +14,8 @@ test_that("Original columns keep same type", {
                        remove_first_dummy = TRUE)$animals, "factor")
   expect_is(dummy_cols(fastDummies_example,
                        remove_first_dummy = TRUE)$dates, "Date")
-  expect_is(dummy_cols(c("a", "b", "c"))$data, "character")
-  expect_is(dummy_cols(c(1.1, 1.2, 1.3))$data, "numeric")
+  expect_is(dummy_cols(c("a", "b", "c"))$.data, "character")
+  expect_is(dummy_cols(c(1.1, 1.2, 1.3))$.data, "numeric")
 
 })
 
@@ -26,7 +26,7 @@ test_that("New columns are integer", {
   expect_is(dummy_cols(fastDummies_example,
                        select_columns = "dates")[, "dates_2012-01-01"],
             "integer")
-  expect_is(dummy_cols(c("a", "b", "c"))$data_a, "integer")
-  expect_is(dummy_cols(c(1.1, 1.2, 1.3))$data_1.1, "integer")
+  expect_is(dummy_cols(c("a", "b", "c"))$.data_a, "integer")
+  expect_is(dummy_cols(c(1.1, 1.2, 1.3))$.data_1.1, "integer")
 
 })
